@@ -309,7 +309,6 @@
 #define HAVE_GETTIMEOFDAY 1
 #define HAVE_GETUID 1
 #define HAVE_GMTIME_R 1
-#define HAVE_GRANTPT 1
 #define HAVE_INITGROUPS 1
 #define HAVE_IOCTL 1
 #define HAVE_ISSETUGID 1
@@ -442,13 +441,15 @@
 #define BROKEN_BACKTRACE 1
 #define DLEXT_MAXLEN 7
 #define DLEXT ".bundle"
+#define SOEXT ".dylib"
 #define LIBDIR_BASENAME "lib"
 #define HAVE__SETJMP 1
-#define HAVE_SIGSETJMP 1
-#define RUBY_SETJMP(env) sigsetjmp((env),0)
-#define RUBY_LONGJMP(env,val) siglongjmp((env),val)
-#define RUBY_JMP_BUF sigjmp_buf
+#define RUBY_SETJMP(env) _setjmp((env))
+#define RUBY_LONGJMP(env,val) _longjmp((env),val)
+#define RUBY_JMP_BUF jmp_buf
+#define USE_MODULAR_GC 0
 #define USE_YJIT 0
 #define USE_RJIT 0
 #define RUBY_PLATFORM "x86_64-darwin13"
+#define RB_DEFAULT_PARSER RB_DEFAULT_PARSER_PRISM
 #endif /* INCLUDE_RUBY_CONFIG_H */
